==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dc/dae/network__type_8h.js <==
var network__type_8h =
[
    [ "NetworkCompanyStats", "d2/d32/structNetworkCompanyStats.html", "d2/d32/structNetworkCompanyStats" ],
    [ "NetworkCompanyState", "d1/d0c/structNetworkCompanyState.html", "d1/d0c/structNetworkCompanyState" ],
    [ "AdminIndex", "dc/dae/network__type_8h.html#a42bc00e4b51332cff5e05fcb64b7cbbb", null ],
    [ "ClientIndex", "dc/dae/network__type_8h.html#ab9474229801866e2a2f576998a663d03", null ],
    [ "ClientID", "dc/dae/network__type_8h.html#ab2bba6b3fb68a74214341dd2ae5860d2", [
      [ "INVALID_CLIENT_ID", "dc/dae/network__type_8h.html#ab2bba6b3fb68a74214341dd2ae5860d2a854fb6c5db8ac442d90371c93aed7b8b", null ],
      [ "CLIENT_ID_SERVER", "dc/dae/network__type_8h.html#ab2bba6b3fb68a74214341dd2ae5860d2ac88f4fdfc2e9a05b9de56d1f1568fce3", null ],
      [ "CLIENT_ID_FIRST", "dc/dae/network__type_8h.html#ab2bba6b3fb68a74214341dd2ae5860d2af89d5a34726771ad799af2aa5e5138c9", null ]
    ] ],
    [ "DestType", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384ec", [
      [ "DESTTYPE_BROADCAST", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384ecaa36cfff2fdb8753fab432df3c7320853", null ],
      [ "DESTTYPE_TEAM", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384eca828e0cfbc14ac634566ce19f825eea6f", null ],
      [ "DESTTYPE_CLIENT", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384eca4da3814cd3e15a89b75ab30701f755e7", null ]
    ] ],
    [ "NetworkAction", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19", [
      [ "NETWORK_ACTION_JOIN", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a2731f63d482e51bb9eadc17ec895d3ad", null ],
      [ "NETWORK_ACTION_LEAVE", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a222ac62e2caff32ecebb6bd62fdd5877", null ],
      [ "NETWORK_ACTION_SERVER_MESSAGE", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19ace1a8f99dfb3c27d24f32b35afa924ab", null ],
      [ "NETWORK_ACTION_CHAT", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19af61b06236471dab2c612cfb90743b312", null ],
      [ "NETWORK_ACTION_CHAT_COMPANY", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a70a25f1096d0ee28b12d378e42910035", null ],
      [ "NETWORK_ACTION_CHAT_CLIENT", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19afd3cdf5bc377d26bbaf105e392e6ded6", null ],
      [ "NETWORK_ACTION_GIVE_MONEY", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a093799a14241c22a9c19bbef7df400e9", null ],
      [ "NETWORK_ACTION_NAME_CHANGE", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19ae2ac1696c1bf69b133e86239d0e0aa4c", null ],
      [ "NETWORK_ACTION_COMPANY_SPECTATOR", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a2c762e6d92edc28b5b378eeda19c710b", null ],
      [ "NETWORK_ACTION_COMPANY_JOIN", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a0a642742edb553b78059d424f1cc356b", null ],
      [ "NETWORK_ACTION_COMPANY_NEW", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19acdd7c6ef25fdfc91a23c5b6fe05cc982", null ]
    ] ],
    [ "NetworkErrorCode", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9f", [
      [ "NETWORK_ERROR_GENERAL", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa265f29d82dbcd9b22a15229fcfec446a", null ],
      [ "NETWORK_ERROR_DESYNC", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa79adc2a12d6c8b502a4a7d2296f90702", null ],
      [ "NETWORK_ERROR_SAVEGAME_FAILED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fafcbaa5bbf35bdea4e98a930fb5a1d205", null ],
      [ "NETWORK_ERROR_CONNECTION_LOST", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fae5d47881439c78a45d8dbf8adbb5301a", null ],
      [ "NETWORK_ERROR_ILLEGAL_PACKET", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa20557636f17efff84a1ff46cd06edf33", null ],
      [ "NETWORK_ERROR_NEWGRF_MISMATCH", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fab3cd77e7f6018ee9cd8049105dc6a013", null ],
      [ "NETWORK_ERROR_NOT_AUTHORIZED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa85f33600894bf65cd25cb8f2cefb48e8", null ],
      [ "NETWORK_ERROR_NOT_EXPECTED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fae35d5938db19ce9af0a237affc0f1a86", null ],
      [ "NETWORK_ERROR_WRONG_REVISION", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa18c84fcd105fb5b6d67ca1e5c7004040", null ],
      [ "NETWORK_ERROR_NAME_IN_USE", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa8ba571b84c2cebc4182a236ae273d827", null ],
      [ "NETWORK_ERROR_WRONG_PASSWORD", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa18dac224b817e0282df0bb93644c804c", null ],
      [ "NETWORK_ERROR_COMPANY_MISMATCH", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa73592444dfac85f1b2830b9e3eebe6e8", null ],
      [ "NETWORK_ERROR_KICKED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9facc6010777ba930a4c7baa378d2afd308", null ],
      [ "NETWORK_ERROR_CHEATER", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9faafba2bcffa903a448cd6790523fdc15d", null ],
      [ "NETWORK_ERROR_FULL", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa20dd6849c4cd19ea2f9d4d45304d9821", null ],
      [ "NETWORK_ERROR_TOO_MANY_COMMANDS", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa80879bbd7a30169dffc2f2b287617ffc", null ],
      [ "NETWORK_ERROR_TIMEOUT_PASSWORD", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa1c44d3329fb3ea243f94e6d20058ccad", null ],
      [ "NETWORK_ERROR_TIMEOUT_COMPUTER", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa64561fb5593c1991e45769d129a77552", null ],
      [ "NETWORK_ERROR_TIMEOUT_MAP", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa6a6becee40b02380d665e2b07c8db282", null ],
      [ "NETWORK_ERROR_TIMEOUT_JOIN", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa558a94797ff2fb7e604c410b50255d9a", null ],
      [ "NETWORK_ERROR_END", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa5d5022e4bb2e29f2c0f6e6425a981f2d", null ]
    ] ],
    [ "NetworkPasswordType", "dc/dae/network__type_8h.html#ab3f7542bf944c8a4ef5556634f101f9b", [
      [ "NETWORK_GAME_PASSWORD", "dc/dae/network__type_8h.html#ab3f7542bf944c8a4ef5556634f101f9ba5327c6fe80138290305e3b68fd9ea201", null ],
      [ "NETWORK_COMPANY_PASSWORD", "dc/dae/network__type_8h.html#ab3f7542bf944c8a4ef5556634f101f9ba1d22c81afb9c3737b0c88fa64432b467", null ]
    ] ],
    [ "NetworkVehicleType", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433", [
      [ "NETWORK_VEH_TRAIN", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433ade41e226833dc91d3337836f3248ded9", null ],
      [ "NETWORK_VEH_LORRY", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a2777b0a34e8ac4272a30b7f366bcaad3", null ],
      [ "NETWORK_VEH_BUS", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a63e798762b123fc9092ec40d937cebe0", null ],
      [ "NETWORK_VEH_PLANE", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a3ac1403cd915dca3de3967ff3e387409", null ],
      [ "NETWORK_VEH_SHIP", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a6b1a4be74dd25f47def55422a23ac0c5", null ],
      [ "NETWORK_VEH_END", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433af4e7bf06fd6f5da57ce92b6724dde3d5", null ]
    ] ],
    [ "INVALID_ADMIN_ID", "dc/dae/network__type_8h.html#a0319691c0f7a4d1ad4e2a77570ffd0f0", null ],
    [ "MAX_ADMINS", "dc/dae/network__type_8h.html#af1e3b78377762068463f23e24f7e2283", null ],
    [ "MAX_CLIENT_SLOTS", "dc/dae/network__type_8h.html#a4ace415eba89c4767da7603b79a14bf4", null ],
    [ "MAX_CLIENTS", "dc/dae/network__type_8h.html#a699fb57d41f4c8efa0a54626fbd9fb8a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dc/dae/network__type_8h.js <==
var network__type_8h =
[
    [ "NetworkCompanyStats", "d2/d32/structNetworkCompanyStats.html", "d2/d32/structNetworkCompanyStats" ],
    [ "NetworkCompanyState", "d1/d0c/structNetworkCompanyState.html", "d1/d0c/structNetworkCompanyState" ],
    [ "AdminIndex", "dc/dae/network__type_8h.html#a42bc00e4b51332cff5e05fcb64b7cbbb", null ],
    [ "ClientIndex", "dc/dae/network__type_8h.html#ab9474229801866e2a2f576998a663d03", null ],
    [ "ClientID", "dc/dae/network__type_8h.html#a77374d49581bba4e5482e5dc5aa2b544", [
      [ "INVALID_CLIENT_ID", "dc/dae/network__type_8h.html#a77374d49581bba4e5482e5dc5aa2b544a854fb6c5db8ac442d90371c93aed7b8b", null ],
      [ "CLIENT_ID_SERVER", "dc/dae/network__type_8h.html#a77374d49581bba4e5482e5dc5aa2b544ac88f4fdfc2e9a05b9de56d1f1568fce3", null ],
      [ "CLIENT_ID_FIRST", "dc/dae/network__type_8h.html#a77374d49581bba4e5482e5dc5aa2b544af89d5a34726771ad799af2aa5e5138c9", null ]
    ] ],
    [ "DestType", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384ec", [
      [ "DESTTYPE_BROADCAST", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384ecaa36cfff2fdb8753fab432df3c7320853", null ],
      [ "DESTTYPE_TEAM", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384eca828e0cfbc14ac634566ce19f825eea6f", null ],
      [ "DESTTYPE_CLIENT", "dc/dae/network__type_8h.html#af12671c89e4bd8734376b3f6de7384eca4da3814cd3e15a89b75ab30701f755e7", null ]
    ] ],
    [ "NetworkAction", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19", [
      [ "NETWORK_ACTION_JOIN", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a2731f63d482e51bb9eadc17ec895d3ad", null ],
      [ "NETWORK_ACTION_LEAVE", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a222ac62e2caff32ecebb6bd62fdd5877", null ],
      [ "NETWORK_ACTION_SERVER_MESSAGE", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19ace1a8f99dfb3c27d24f32b35afa924ab", null ],
      [ "NETWORK_ACTION_CHAT", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19af61b06236471dab2c612cfb90743b312", null ],
      [ "NETWORK_ACTION_CHAT_COMPANY", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a70a25f1096d0ee28b12d378e42910035", null ],
      [ "NETWORK_ACTION_CHAT_CLIENT", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19afd3cdf5bc377d26bbaf105e392e6ded6", null ],
      [ "NETWORK_ACTION_GIVE_MONEY", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a093799a14241c22a9c19bbef7df400e9", null ],
      [ "NETWORK_ACTION_NAME_CHANGE", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19ae2ac1696c1bf69b133e86239d0e0aa4c", null ],
      [ "NETWORK_ACTION_COMPANY_SPECTATOR", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a2c762e6d92edc28b5b378eeda19c710b", null ],
      [ "NETWORK_ACTION_COMPANY_JOIN", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19a0a642742edb553b78059d424f1cc356b", null ],
      [ "NETWORK_ACTION_COMPANY_NEW", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19acdd7c6ef25fdfc91a23c5b6fe05cc982", null ],
      [ "NETWORK_ACTION_KICKED", "dc/dae/network__type_8h.html#a86a0bbadf71952cf48f9a41f3f65ab19afaa86261fe48c83509e8880bac86aa79", null ]
    ] ],
    [ "NetworkErrorCode", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9f", [
      [ "NETWORK_ERROR_GENERAL", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa265f29d82dbcd9b22a15229fcfec446a", null ],
      [ "NETWORK_ERROR_DESYNC", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa79adc2a12d6c8b502a4a7d2296f90702", null ],
      [ "NETWORK_ERROR_SAVEGAME_FAILED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fafcbaa5bbf35bdea4e98a930fb5a1d205", null ],
      [ "NETWORK_ERROR_CONNECTION_LOST", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fae5d47881439c78a45d8dbf8adbb5301a", null ],
      [ "NETWORK_ERROR_ILLEGAL_PACKET", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa20557636f17efff84a1ff46cd06edf33", null ],
      [ "NETWORK_ERROR_NEWGRF_MISMATCH", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fab3cd77e7f6018ee9cd8049105dc6a013", null ],
      [ "NETWORK_ERROR_NOT_AUTHORIZED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa85f33600894bf65cd25cb8f2cefb48e8", null ],
      [ "NETWORK_ERROR_NOT_EXPECTED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fae35d5938db19ce9af0a237affc0f1a86", null ],
      [ "NETWORK_ERROR_WRONG_REVISION", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa18c84fcd105fb5b6d67ca1e5c7004040", null ],
      [ "NETWORK_ERROR_NAME_IN_USE", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa8ba571b84c2cebc4182a236ae273d827", null ],
      [ "NETWORK_ERROR_WRONG_PASSWORD", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa18dac224b817e0282df0bb93644c804c", null ],
      [ "NETWORK_ERROR_COMPANY_MISMATCH", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa73592444dfac85f1b2830b9e3eebe6e8", null ],
      [ "NETWORK_ERROR_KICKED", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9facc6010777ba930a4c7baa378d2afd308", null ],
      [ "NETWORK_ERROR_CHEATER", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9faafba2bcffa903a448cd6790523fdc15d", null ],
      [ "NETWORK_ERROR_FULL", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa20dd6849c4cd19ea2f9d4d45304d9821", null ],
      [ "NETWORK_ERROR_TOO_MANY_COMMANDS", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa80879bbd7a30169dffc2f2b287617ffc", null ],
      [ "NETWORK_ERROR_TIMEOUT_PASSWORD", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa1c44d3329fb3ea243f94e6d20058ccad", null ],
      [ "NETWORK_ERROR_TIMEOUT_COMPUTER", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa64561fb5593c1991e45769d129a77552", null ],
      [ "NETWORK_ERROR_TIMEOUT_MAP", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa6a6becee40b02380d665e2b07c8db282", null ],
      [ "NETWORK_ERROR_TIMEOUT_JOIN", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa558a94797ff2fb7e604c410b50255d9a", null ],
      [ "NETWORK_ERROR_END", "dc/dae/network__type_8h.html#acd4a8d586c00ae4fa21c42647a1f0f9fa5d5022e4bb2e29f2c0f6e6425a981f2d", null ]
    ] ],
    [ "NetworkPasswordType", "dc/dae/network__type_8h.html#ab3f7542bf944c8a4ef5556634f101f9b", [
      [ "NETWORK_GAME_PASSWORD", "dc/dae/network__type_8h.html#ab3f7542bf944c8a4ef5556634f101f9ba5327c6fe80138290305e3b68fd9ea201", null ],
      [ "NETWORK_COMPANY_PASSWORD", "dc/dae/network__type_8h.html#ab3f7542bf944c8a4ef5556634f101f9ba1d22c81afb9c3737b0c88fa64432b467", null ]
    ] ],
    [ "NetworkVehicleType", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433", [
      [ "NETWORK_VEH_TRAIN", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433ade41e226833dc91d3337836f3248ded9", null ],
      [ "NETWORK_VEH_LORRY", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a2777b0a34e8ac4272a30b7f366bcaad3", null ],
      [ "NETWORK_VEH_BUS", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a63e798762b123fc9092ec40d937cebe0", null ],
      [ "NETWORK_VEH_PLANE", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a3ac1403cd915dca3de3967ff3e387409", null ],
      [ "NETWORK_VEH_SHIP", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433a6b1a4be74dd25f47def55422a23ac0c5", null ],
      [ "NETWORK_VEH_END", "dc/dae/network__type_8h.html#ab260dcf19e57a0384f9d4e3cfe9a2433af4e7bf06fd6f5da57ce92b6724dde3d5", null ]
    ] ],
    [ "INVALID_ADMIN_ID", "dc/dae/network__type_8h.html#a0319691c0f7a4d1ad4e2a77570ffd0f0", null ],
    [ "MAX_ADMINS", "dc/dae/network__type_8h.html#af1e3b78377762068463f23e24f7e2283", null ],
    [ "MAX_CLIENT_SLOTS", "dc/dae/network__type_8h.html#a4ace415eba89c4767da7603b79a14bf4", null ],
    [ "MAX_CLIENTS", "dc/dae/network__type_8h.html#a699fb57d41f4c8efa0a54626fbd9fb8a", null ]
];
